import { Injectable } from '@angular/core';
import { Observable } from 'rxjs/Observable';
import { RPCClient } from 'packages/core/rpc/client/RPCClient';
import {
  DiscoveryStartInfo,
  DiscoveryZone,
  DiscoveryHost,
  DiscoveryPort,
  DiscoveryService as M_DiscoveryService,
  Zone,
  Host,
  Port,
  Service,
} from '../model';

@Injectable()
export class DiscoveryService {

  public constructor(
    private rpcClient: RPCClient,
  ) {

  }

  public start(dsInfo: DiscoveryStartInfo): Observable<DiscoveryStartInfo> {

    return this.rpcClient.call('DiscoveryService.startDiscovery', dsInfo);
  }

  public discoverZone(probeID: string, discoveryZone: DiscoveryZone): void {
    this.rpcClient.send('DiscoveryService.discoverZone', probeID, discoveryZone);
  }
  public discoverHost(probeID: string, zone: Zone, discoveryHost: DiscoveryHost): void {
    this.rpcClient.send('DiscoveryService.discoverHost', probeID, zone, discoveryHost);
  }
  public discoverPort(probeID: string, host: Host, discoveryPort: DiscoveryPort): void {
    this.rpcClient.send('DiscoveryService.discoverPort', probeID, host, discoveryPort);
  }
  public discoverService(probeID: string, port: Port, discoveryService: M_DiscoveryService): void {
    this.rpcClient.send('DiscoveryService.discoverService', probeID, port, discoveryService);
  }
}
