import { Injectable } from '@angular/core';
import { Router } from '@angular/router';

import { Effect, Actions, ofType } from '@ngrx/effects';
import { Action } from '@ngrx/store';

import { Observable } from 'rxjs/Observable';
import { of } from 'rxjs/observable/of';

import 'rxjs/add/operator/catch';
import 'rxjs/add/operator/do';
import 'rxjs/add/operator/exhaustMap';
import 'rxjs/add/operator/switchMap';
import 'rxjs/add/operator/map';
import 'rxjs/add/operator/take';

import { RESTError } from 'packages/core/rest/error';
import { MemberTotpService } from '../../service/member-totp.service';

import {
  CreateTotp,
  CreateTotpSuccess,
  CreateTotpFailure,

  Regist,
  RegistSuccess,
  RegistFailure,

  ActionType,
} from './totp.action';

@Injectable()
export class Effects {
  private _returnURL: any;

  constructor(
    private actions$: Actions,
    private memberTotpService: MemberTotpService,
    private router: Router
  ) { }

  @Effect()
  createTotp$: Observable<Action> = this.actions$
    .ofType(ActionType.CreateTotp)
    .map((action: CreateTotp) => action.payload)
    .switchMap(payload => {
      // this._returnURL = payload.returnURL;
      return this.memberTotpService.createTotp(payload.member);
    })
    .map((result: any) => {
      const key = result['key'];
      const uri = result['uri'];
      return new CreateTotpSuccess({key: key, uri: uri});
    })
    .catch((error: RESTError) => {
      return of(new CreateTotpFailure(error));
    });

  @Effect({ dispatch: false })
  createTotpSuccess$ = this.actions$
    .ofType(ActionType.CreateTotpSuccess)
    .do(() => {
    // Todo TOTP View Print
      this.router.navigateByUrl(this._returnURL);
    });

  @Effect()
  regist: Observable<Action> = this.actions$
    .ofType(ActionType.Regist)
    .map((action: Regist) => action.payload)
    .switchMap((payload) => {
      // this._returnURL = payload.returnURL;
      return this.memberTotpService.regist(payload.member, payload.secretCode, payload.code);
    })
    .map((result: any) => {
      return new RegistSuccess(result);
    })
    .catch((error: RESTError) => {
      return of(new RegistFailure(error));
    });
}
